pub struct DataRequest {
pub handler_info: HandlerInfo,
pub data: Vec<u8>,
pub s_type: Box<dyn StructureType>,
}Expand description
‘handler_info’ info about target handler ‘data’ the request payload. E.g structure that will be deserialized on server side. ‘s_type’ structure type indetifiers what data is send and how handler on server side will process this data.
Fields
handler_info: HandlerInfodata: Vec<u8>s_type: Box<dyn StructureType>Auto Trait Implementations
impl Freeze for DataRequest
impl !RefUnwindSafe for DataRequest
impl Send for DataRequest
impl Sync for DataRequest
impl Unpin for DataRequest
impl UnsafeUnpin for DataRequest
impl !UnwindSafe for DataRequest