RequestChannel

Type Alias RequestChannel 

pub type RequestChannel<C> = (Sender<Arc<Mutex<dyn Handler<Codec = C>>>>, Receiver<Arc<Mutex<dyn Handler<Codec = C>>>>);
The request channel, used to move out tcp stream out of server control.

When the stream is moved, the server does not own it anymore.

If there is a need to return the stream, only reconnect is available.