Modules
Structs
- Client
Connect - Client
Request - Wraps a data request and the channel that receives the server response.
- Data
Request handler_info— info about the target handler.data— the request payload (serialized structure).s_type— identifies what data is sent and how the server handler processes it.- Handler
Info - Describes the target handler on the server.